package org.apache.bcel.generic;

import java.io.DataOutputStream;
import java.io.IOException;
import org.apache.bcel.Const;
import org.apache.bcel.classfile.ConstantPool;
import org.apache.bcel.util.ByteSequence;

/* loaded from: org_apache_bcel_generic.jar:org/apache/bcel/generic/Instruction.class */
public abstract class Instruction implements Cloneable {
    static final Instruction[] EMPTY_ARRAY = new Instruction[0];
    private static InstructionComparator cmp = InstructionComparator.DEFAULT;

    @Deprecated
    protected short length;

    @Deprecated
    protected short opcode;

    public abstract void accept(Visitor visitor);

    @Deprecated
    public static InstructionComparator getComparator() {
        return cmp;
    }

    public static boolean isValidByte(int value) {
        return value >= -128 && value <= 127;
    }

    public static boolean isValidShort(int value) {
        return value >= -32768 && value <= 32767;
    }

    public static Instruction readInstruction(ByteSequence bytes) throws IOException {
        Instruction obj;
        boolean wide = false;
        short opcode = (short) bytes.readUnsignedByte();
        if (opcode == 196) {
            wide = true;
            opcode = (short) bytes.readUnsignedByte();
        }
        Instruction instruction = InstructionConst.getInstruction(opcode);
        if (instruction != null) {
            return instruction;
        }
        switch (opcode) {
            case 16:
                obj = new BIPUSH();
                break;
            case 17:
                obj = new SIPUSH();
                break;
            case 18:
                obj = new LDC();
                break;
            case 19:
                obj = new LDC_W();
                break;
            case 20:
                obj = new LDC2_W();
                break;
            case 21:
                obj = new ILOAD();
                break;
            case 22:
                obj = new LLOAD();
                break;
            case 23:
                obj = new FLOAD();
                break;
            case 24:
                obj = new DLOAD();
                break;
            case 25:
                obj = new ALOAD();
                break;
            case 26:
                obj = new ILOAD(0);
                break;
            case 27:
                obj = new ILOAD(1);
                break;
            case 28:
                obj = new ILOAD(2);
                break;
            case 29:
                obj = new ILOAD(3);
                break;
            case 30:
                obj = new LLOAD(0);
                break;
            case 31:
                obj = new LLOAD(1);
                break;
            case 32:
                obj = new LLOAD(2);
                break;
            case 33:
                obj = new LLOAD(3);
                break;
            case 34:
                obj = new FLOAD(0);
                break;
            case 35:
                obj = new FLOAD(1);
                break;
            case 36:
                obj = new FLOAD(2);
                break;
            case 37:
                obj = new FLOAD(3);
                break;
            case 38:
                obj = new DLOAD(0);
                break;
            case 39:
                obj = new DLOAD(1);
                break;
            case 40:
                obj = new DLOAD(2);
                break;
            case 41:
                obj = new DLOAD(3);
                break;
            case 42:
                obj = new ALOAD(0);
                break;
            case 43:
                obj = new ALOAD(1);
                break;
            case 44:
                obj = new ALOAD(2);
                break;
            case 45:
                obj = new ALOAD(3);
                break;
            case 46:
            case 47:
            case 48:
            case 49:
            case 50:
            case 51:
            case 52:
            case 53:
            case 79:
            case 80:
            case 81:
            case 82:
            case ElementValueGen.PRIMITIVE_SHORT /* 83 */:
            case 84:
            case 85:
            case 86:
            case 87:
            case 88:
            case 89:
            case ElementValueGen.PRIMITIVE_BOOLEAN /* 90 */:
            case ElementValueGen.ARRAY /* 91 */:
            case 92:
            case 93:
            case 94:
            case 95:
            case 96:
            case 97:
            case 98:
            case ElementValueGen.CLASS /* 99 */:
            case 100:
            case ElementValueGen.ENUM_CONSTANT /* 101 */:
            case 102:
            case 103:
            case 104:
            case 105:
            case 106:
            case 107:
            case 108:
            case 109:
            case 110:
            case 111:
            case 112:
            case 113:
            case 114:
            case ElementValueGen.STRING /* 115 */:
            case 116:
            case 117:
            case 118:
            case 119:
            case 120:
            case 121:
            case 122:
            case 123:
            case 124:
            case 125:
            case 126:
            case 127:
            case 128:
            case 129:
            case 130:
            case 131:
            case 133:
            case 134:
            case 135:
            case 136:
            case 137:
            case 138:
            case 139:
            case 140:
            case 141:
            case 142:
            case 143:
            case 144:
            case 145:
            case 146:
            case 147:
            case 148:
            case 149:
            case 150:
            case 151:
            case 152:
            case 172:
            case 173:
            case 174:
            case 175:
            case 176:
            case 177:
            case 190:
            case 191:
            case 194:
            case 195:
            case 196:
            case 203:
            case 204:
            case 205:
            case 206:
            case 207:
            case 208:
            case 209:
            case 210:
            case 211:
            case 212:
            case 213:
            case 214:
            case 215:
            case 216:
            case 217:
            case 218:
            case 219:
            case 220:
            case 221:
            case 222:
            case 223:
            case 224:
            case 225:
            case 226:
            case 227:
            case 228:
            case 229:
            case 230:
            case 231:
            case 232:
            case 233:
            case 234:
            case 235:
            case 236:
            case 237:
            case 238:
            case 239:
            case 240:
            case 241:
            case 242:
            case 243:
            case 244:
            case 245:
            case 246:
            case 247:
            case 248:
            case 249:
            case 250:
            case 251:
            case 252:
            case 253:
            default:
                throw new ClassGenException("Illegal opcode detected: " + ((int) opcode));
            case 54:
                obj = new ISTORE();
                break;
            case 55:
                obj = new LSTORE();
                break;
            case 56:
                obj = new FSTORE();
                break;
            case 57:
                obj = new DSTORE();
                break;
            case 58:
                obj = new ASTORE();
                break;
            case 59:
                obj = new ISTORE(0);
                break;
            case 60:
                obj = new ISTORE(1);
                break;
            case 61:
                obj = new ISTORE(2);
                break;
            case 62:
                obj = new ISTORE(3);
                break;
            case 63:
                obj = new LSTORE(0);
                break;
            case ElementValueGen.ANNOTATION /* 64 */:
                obj = new LSTORE(1);
                break;
            case 65:
                obj = new LSTORE(2);
                break;
            case ElementValueGen.PRIMITIVE_BYTE /* 66 */:
                obj = new LSTORE(3);
                break;
            case ElementValueGen.PRIMITIVE_CHAR /* 67 */:
                obj = new FSTORE(0);
                break;
            case ElementValueGen.PRIMITIVE_DOUBLE /* 68 */:
                obj = new FSTORE(1);
                break;
            case 69:
                obj = new FSTORE(2);
                break;
            case ElementValueGen.PRIMITIVE_FLOAT /* 70 */:
                obj = new FSTORE(3);
                break;
            case 71:
                obj = new DSTORE(0);
                break;
            case 72:
                obj = new DSTORE(1);
                break;
            case ElementValueGen.PRIMITIVE_INT /* 73 */:
                obj = new DSTORE(2);
                break;
            case ElementValueGen.PRIMITIVE_LONG /* 74 */:
                obj = new DSTORE(3);
                break;
            case 75:
                obj = new ASTORE(0);
                break;
            case 76:
                obj = new ASTORE(1);
                break;
            case 77:
                obj = new ASTORE(2);
                break;
            case 78:
                obj = new ASTORE(3);
                break;
            case 132:
                obj = new IINC();
                break;
            case 153:
                obj = new IFEQ();
                break;
            case 154:
                obj = new IFNE();
                break;
            case 155:
                obj = new IFLT();
                break;
            case 156:
                obj = new IFGE();
                break;
            case 157:
                obj = new IFGT();
                break;
            case 158:
                obj = new IFLE();
                break;
            case 159:
                obj = new IF_ICMPEQ();
                break;
            case 160:
                obj = new IF_ICMPNE();
                break;
            case 161:
                obj = new IF_ICMPLT();
                break;
            case 162:
                obj = new IF_ICMPGE();
                break;
            case 163:
                obj = new IF_ICMPGT();
                break;
            case 164:
                obj = new IF_ICMPLE();
                break;
            case 165:
                obj = new IF_ACMPEQ();
                break;
            case 166:
                obj = new IF_ACMPNE();
                break;
            case 167:
                obj = new GOTO();
                break;
            case 168:
                obj = new JSR();
                break;
            case 169:
                obj = new RET();
                break;
            case 170:
                obj = new TABLESWITCH();
                break;
            case 171:
                obj = new LOOKUPSWITCH();
                break;
            case 178:
                obj = new GETSTATIC();
                break;
            case 179:
                obj = new PUTSTATIC();
                break;
            case 180:
                obj = new GETFIELD();
                break;
            case 181:
                obj = new PUTFIELD();
                break;
            case 182:
                obj = new INVOKEVIRTUAL();
                break;
            case 183:
                obj = new INVOKESPECIAL();
                break;
            case 184:
                obj = new INVOKESTATIC();
                break;
            case 185:
                obj = new INVOKEINTERFACE();
                break;
            case 186:
                obj = new INVOKEDYNAMIC();
                break;
            case 187:
                obj = new NEW();
                break;
            case 188:
                obj = new NEWARRAY();
                break;
            case 189:
                obj = new ANEWARRAY();
                break;
            case 192:
                obj = new CHECKCAST();
                break;
            case 193:
                obj = new INSTANCEOF();
                break;
            case 197:
                obj = new MULTIANEWARRAY();
                break;
            case 198:
                obj = new IFNULL();
                break;
            case 199:
                obj = new IFNONNULL();
                break;
            case 200:
                obj = new GOTO_W();
                break;
            case 201:
                obj = new JSR_W();
                break;
            case 202:
                obj = new BREAKPOINT();
                break;
            case 254:
                obj = new IMPDEP1();
                break;
            case 255:
                obj = new IMPDEP2();
                break;
        }
        if (wide && !(obj instanceof LocalVariableInstruction) && !(obj instanceof RET)) {
            throw new ClassGenException("Illegal opcode after wide: " + ((int) opcode));
        }
        obj.setOpcode(opcode);
        obj.initFromFile(bytes, wide);
        return obj;
    }

    @Deprecated
    public static void setComparator(InstructionComparator c) {
        cmp = c;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public Instruction() {
        this.length = (short) 1;
        this.opcode = (short) -1;
    }

    public Instruction(short opcode, short length) {
        this.length = (short) 1;
        this.opcode = (short) -1;
        this.length = length;
        this.opcode = opcode;
    }

    public int consumeStack(ConstantPoolGen cpg) {
        return Const.getConsumeStack(this.opcode);
    }

    public Instruction copy() {
        Instruction i = null;
        if (InstructionConst.getInstruction(getOpcode()) != null) {
            i = this;
        } else {
            try {
                i = (Instruction) clone();
            } catch (CloneNotSupportedException e) {
                System.err.println(e);
            }
        }
        return i;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public void dispose() {
    }

    public void dump(DataOutputStream out) throws IOException {
        out.writeByte(this.opcode);
    }

    public boolean equals(Object that) {
        return (that instanceof Instruction) && cmp.equals(this, (Instruction) that);
    }

    public int getLength() {
        return this.length;
    }

    public String getName() {
        return Const.getOpcodeName(this.opcode);
    }

    public short getOpcode() {
        return this.opcode;
    }

    public int hashCode() {
        return this.opcode;
    }

    protected void initFromFile(ByteSequence bytes, boolean wide) throws IOException {
    }

    public int produceStack(ConstantPoolGen cpg) {
        return Const.getProduceStack(this.opcode);
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public final void setLength(int length) {
        this.length = (short) length;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public final void setOpcode(short opcode) {
        this.opcode = opcode;
    }

    public String toString() {
        return toString(true);
    }

    public String toString(boolean verbose) {
        if (verbose) {
            return getName() + "[" + ((int) this.opcode) + "](" + ((int) this.length) + ")";
        }
        return getName();
    }

    public String toString(ConstantPool cp) {
        return toString(false);
    }
}
